@@ -13,7 +13,7 @@ from omas import *
 os.environ['OMAS_DEBUG_TOPIC'] = 'dynamic'
 
 # generate some data and save it in IMAS
-ods = ods_sample(ntimes=2)
+ods = ODS().sample(ntimes=2)
 ods.save('imas', os.environ['USER'], 'DIII-D', 1000, 0, new=True, verbose=True)
 
 # ODS.open() will keep the file descriptor open so that OMAS
