@@ -26,7 +26,7 @@ def through_omas_suite(ods=None, test_type=None, do_raise=False):
     """
 
     if ods is None:
-        ods = ods_sample()
+        ods = ODS().sample()
 
     if test_type in _tests:
         os.environ['OMAS_DEBUG_TOPIC'] = test_type
