@@ -224,22 +224,15 @@ def summary_taue(ods, update=True):
                     n_tritium_avg = numpy.trapz(ions[ion]['density_thermal'], x=volume)
             isotope_factor = (2.014102 * n_deuterium_avg + 3.016049 * n_tritium_avg) / (n_deuterium_avg + n_tritium_avg)
 
-            # Find P_aux from core_sources ods:
-            pow_prof = numpy.zeros(len(ne))
-            sources = ods['core_sources']['source']
-            for source in ods['core_sources']['source']:
-                if 'identifier' not in sources[source] or 'index' not in sources[source]['identifier']:
-                    printe(sources[source].location + "['identifier']['index'] is empty, see: https://gafusion.github.io/omas/schema/schema_core%20sources.html")
-                elif sources[source]['identifier']['index'] == 100:
-                    if 'total_ion_energy' in sources[source]['profiles_1d'][time_index]:
-                        pow_prof += sources[source]['profiles_1d'][time_index]['total_ion_energy']
-                    elif 'electrons' in sources[source]['profiles_1d'][time_index]:
-                        pow_prof += sources[source]['profiles_1d'][time_index]['electrons']['energy']
-            p_aux = numpy.trapz(pow_prof, x=volume)
-            tau_e = abs(56.2e-3 * (abs(ip) / 1e6) ** 0.93 * abs(bt) ** 0.15 * (ne_vol_avg / 1e19) ** 0.41 * (p_aux / 1e6) ** -0.69 * r_major ** 1.97 * kappa ** 0.78 * aspect ** -0.58 * isotope_factor ** 0.19)  # [s]
+            # Get total power from ods function:
+            ods.physics_summary_total_powers()
+            total_power = ods['summary.global_quantities.power_steady.value'][time_index]
+
+            # Calculate tau_e
+            tau_e = abs(56.2e-3 * (abs(ip) / 1e6) ** 0.93 * abs(bt) ** 0.15 * (ne_vol_avg / 1e19) ** 0.41 * (total_power / 1e6) ** -0.69 * r_major ** 1.97 * kappa ** 0.78 * aspect ** -0.58 * isotope_factor ** 0.19)  # [s]
             # print('kap', kappa, 'bt', bt, 'ip', ip, 'ne_vol', ne_vol_avg, 'paux', p_aux, 'aspect', aspect, 'isotope', isotope_factor, 'tau_e', tau_e)
             tau_e_scaling.append(tau_e)
-            tau_e_MHD.append(equilibrium_ods['global_quantities']['energy_mhd'] / p_aux)
+            tau_e_MHD.append(equilibrium_ods['global_quantities']['energy_mhd'] / total_power)
 
     # assign quantities in the ODS
     ods_n['summary']['global_quantities']['tau_energy_98']['value'] = numpy.array(tau_e_scaling)
@@ -249,6 +242,61 @@ def summary_taue(ods, update=True):
 
     return ods_n
 
+@add_to__ODS__
+@preprocess_ods('core_sources')
+def summary_total_powers(ods, update=True):
+    """
+    Integrate power densities to the total and heating and current drive systems and fills summary.globalquantities
+    :param ods: input ods
+
+    :param update: operate in place
+
+    :return: updated ods
+    """
+    ods_n = ods
+    if not update:
+        from omas import ODS
+        ods_n = ODS().copy_attrs_from(ods)
+
+    sources = ods_n['core_sources']['source']
+    index_dict = {2: 'nbi', 3: 'ec', 4: 'lh', 5: 'ic'}
+    power_dict = {'total': [], 'nbi': [], 'ec': [], 'lh': [], 'ic': []}
+    q_init = numpy.zeros(len(sources[0]['profiles_1d'][0]['grid']['rho_tor_norm']))
+    q_dict = {'total': copy.deepcopy(q_init), 'nbi': copy.deepcopy(q_init),
+              'ec': copy.deepcopy(q_init), 'lh': copy.deepcopy(q_init),
+              'ic': copy.deepcopy(q_init)}
+
+    ignore_indices = list(range(100, 108)) + list(range(900,910))
+
+    for time_index in sources[0]['profiles_1d']:
+        vol = sources[0]['profiles_1d'][time_index]['grid']['volume']
+        for source in sources:
+            if sources[source]['identifier.index'] in ignore_indices:
+                # Skip the combined sources to prevent double counting
+                continue
+            if 'electrons' in sources[source]['profiles_1d'][time_index] and 'energy' in \
+                    sources[source]['profiles_1d'][time_index]['electrons']:
+                q_dict['total'] += sources[source]['profiles_1d'][time_index]['electrons']['energy']
+                if sources[source]['identifier.index'] in index_dict:
+                    q_dict[index_dict[sources[source]['identifier.index']]] += \
+                    sources[source]['profiles_1d'][time_index]['electrons']['energy']
+            if 'total_ion_energy' in sources[source]['profiles_1d'][time_index]:
+                q_dict['total'] += sources[source]['profiles_1d'][time_index]['total_ion_energy']
+                if sources[source]['identifier.index'] in index_dict:
+                    q_dict[index_dict[sources[source]['identifier.index']]] += \
+                    sources[source]['profiles_1d'][time_index]['total_ion_energy']
+
+        for key, value in power_dict.items():
+            power_dict[key].append(numpy.trapz(q_dict[key], x=vol))
+
+    for key, value in power_dict.items():
+        if numpy.sum(value) > 0:
+            if key is 'total':
+                ods_n['summary.global_quantities.power_steady.value'] = numpy.array(value)
+                continue
+            ods_n[f'summary.heating_current_drive.{key}[0].power.value'] = numpy.array(value)
+
+    return ods_n
 
 @add_to__ODS__
 @preprocess_ods()
@@ -1029,6 +1077,7 @@ def scatter_to_rectangular(r, z, data, R, Z, method=['nearest', 'linear', 'cubic
     :return: R, Z, interpolated_data (and cache if return_cache)
     '''
     import scipy
+    from scipy import interpolate
 
     if isinstance(R, int) and isinstance(Z, int):
         R, Z = numpy.meshgrid(numpy.linspace(numpy.min(r), numpy.max(r), R), numpy.linspace(numpy.min(z), numpy.max(z), Z))
