@@ -1,5 +1,7 @@
 from omas.omas_setup import omas_rcparams
 import os
+import warnings
+from omas.tests.warning_setup import hard_warnings, set_omas_warnings
 
 try:
     import imas
@@ -44,11 +46,13 @@ try:
 except (ImportError, ServerSelectionTimeoutError) as _excp:
     failed_MONGO = _excp
 
-try:
-    from omfit.classes.omfit_eqdsk import OMFITgeqdsk, OMFITsrc
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore')
+    try:
+        from omfit.classes.omfit_eqdsk import OMFITgeqdsk, OMFITsrc
 
-    failed_OMFIT = False
-except ImportError as _excp:
-    failed_OMFIT = _excp
+        failed_OMFIT = False
+    except ImportError as _excp:
+        failed_OMFIT = _excp
 
 __all__ = ['failed_IMAS', 'failed_HDC', 'failed_S3', 'failed_MONGO', 'failed_OMFIT', 'failed_UDA']
