@@ -36,7 +36,7 @@ class TestOmasPlot(unittest.TestCase):
     """
 
     # Sample data for use in tests
-    ods = ods_sample()
+    ods = ODS().sample()
 
     def setUp(self):
         test_id = self.id()
@@ -218,15 +218,8 @@ class TestOmasPlot(unittest.TestCase):
     def test_core_profiles(self):
         ods2 = copy.deepcopy(self.ods)
         ods2.sample_core_profiles()
-        ods2.plot_core_profiles_summary(fig=pyplot.gcf())
-        ods2.plot_core_profiles_summary(
-            fig=pyplot.figure('TestOmasPlot.test_core_profiles totals only'), show_thermal_fast_breakdown=False,
-            show_total_density=True)
-        ods2.plot_core_profiles_summary(
-            fig=pyplot.figure('TestOmasPlot.test_core_profiles total and breakdown'), show_thermal_fast_breakdown=True,
-            show_total_density=True)
-        ods2.plot_core_profiles_summary(
-            fig=pyplot.figure('TestOmasPlot.test_core_profiles no combine temp/dens'), combine_dens_temps=False)
+        ods2.plot_core_profiles_summary(fig=pyplot.figure())
+        ods2.plot_core_profiles_summary(fig=pyplot.figure(),quantities=['temperature', 'density_thermal','j_tor','zeff'], ods_species=[-1,0], lw=3, ls='--')
 
     def test_core_transport(self):
         ods_test = copy.deepcopy(self.ods)
@@ -234,11 +227,9 @@ class TestOmasPlot(unittest.TestCase):
         ods_test['core_transport.ids_properties.comment'] = "TGRYO"
         ods_test.sample_core_profiles()
         ods_test.sample_equilibrium()
-        ods_test['core_profiles.profiles_1d.0.rotation_frequency_tor_sonic'] = numpy.linspace(4e4, 2e3, len(ods_test['core_profiles.profiles_1d.0.grid.rho_tor_norm']))
         ods_test.plot_core_transport_fluxes()
-        fig, axes = pyplot.subplots(nrows=4, ncols=2, sharex='col')
-        ods_test.plot_core_transport_fluxes(fig=fig, axes=axes, show_total_density=False, plotting_label="test")
-        ods_test.plot_core_transport_fluxes(plot_zeff=True, plotting_label="test")
+        ods_test.plot_core_transport_fluxes(show_total_density=False, label='test')
+        ods_test.plot_core_transport_fluxes(plot_zeff=True, label="test")
 
     def test_core_pressure(self):
         ods2 = copy.deepcopy(self.ods)
@@ -494,6 +485,22 @@ class TestOmasPlot(unittest.TestCase):
         # Test relevant plots with basic/default/minimal options
         ods.plot_nbi_summary()
 
+    def test_ods_time_plot(self):
+        # generate some time-dependent data
+        ods = ODS().sample(2)
+
+        # omas plot for pressures
+        ods.plot_core_profiles_pressures()
+
+        # omas plot for core profiles
+        ods.plot_core_profiles_summary()
+
+        # omas plot for equilibrium
+        omas_plot.equilibrium_summary(ods, linewidth=1, label='my equilibrium')
+
+        # omas plot for transport fluxes
+        ods.plot_core_transport_fluxes()
+
 
 if __name__ == '__main__':
     suite = unittest.TestLoader().loadTestsFromTestCase(TestOmasPlot)
